'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.execute = exports.buildMatchIndex = exports.findMatchOffsets = exports.findSpeechOffsets = exports.matchesToIntervals = undefined;

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _intervalTree1d = require('interval-tree-1d');

var _intervalTree1d2 = _interopRequireDefault(_intervalTree1d);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var matchesToIntervals = exports.matchesToIntervals = function matchesToIntervals(matches) {
  return matches.map(function (match) {
    return [match.index, match.index + match[0].length];
  });
};

var findSpeechOffsets = exports.findSpeechOffsets = function findSpeechOffsets(speech) {
  return speech.reduce(function (_ref, segment) {
    var _ref2 = (0, _slicedToArray3.default)(_ref, 2);

    var start = _ref2[0];
    var offsets = _ref2[1];

    var end = start + segment.text.length;
    offsets.push([start, end]);
    return [end + 1, offsets];
  }, [0, []])[1];
};

var findMatchOffsets = exports.findMatchOffsets = function findMatchOffsets(speech, matches) {
  var tree = (0, _intervalTree1d2.default)(matchesToIntervals(matches));
  return findSpeechOffsets(speech).map(function (_ref3) {
    var _ref4 = (0, _slicedToArray3.default)(_ref3, 2);

    var start = _ref4[0];
    var end = _ref4[1];

    var highlights = [];
    tree.queryInterval(start, end, function (match) {
      highlights.push([Math.max(0, match[0] - start), Math.min(end - start, match[1] - start)]);
    });
    return highlights.sort(function (a, b) {
      return a[0] - b[0];
    });
  });
};

var buildMatchIndex = exports.buildMatchIndex = function buildMatchIndex(turns, re) {
  return _immutable2.default.fromJS(turns.map(function (turn) {
    var text = turn.sentences.join(' ');
    var match = undefined,
        matches = [];
    if (re !== null) {
      while ((match = re.exec(text)) !== null) {
        matches.push(match);
      }
    }
    return findMatchOffsets(turn.speech, matches);
  }));
};

var execute = exports.execute = function execute(turns) {
  var re = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

  var matches = buildMatchIndex(turns, re);
  var times = _immutable2.default.List();
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = (0, _getIterator3.default)(matches.entries()), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var _step$value = (0, _slicedToArray3.default)(_step.value, 2);

      var ti = _step$value[0];
      var t = _step$value[1];
      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = (0, _getIterator3.default)(t.entries()), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var _step2$value = (0, _slicedToArray3.default)(_step2.value, 2);

          var si = _step2$value[0];
          var s = _step2$value[1];

          if (s.size > 0) times = times.push(turns[ti].speech[si].start);
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return _immutable2.default.Map({ matches: matches,
    times: times,
    count: matches.flatten(2).size
  });
};